==> Ado-0.43.tar.gz: Ado-0.43/public/doc/en/cover.md <==
#About Ado

<div class="ui hidden">
  If you read this page out of /help/en/* the links in it will not work!
</div>

Ado is an application for managing the enterprise.

It is created by Krasimir Berov with the help of many people from around the world.
The application source code is open. This means **you can use it freely**
and change it for your own purposes as far as you know how.
The license under which it is distributed is 
[LGPL &mdash; версия 3](http://opensource.org/licenses/lgpl-3.0.html). 
Many software libraries made by different software authors are used.
All libraries are carefully chosen and are distributed under licenses which allow them to be freely distributed even for commercial purposes according to the specific license.
You can always **download the last stable release from
[https://metacpan.org/release/Ado](https://metacpan.org/release/Ado)**.

The author offers **payed services** with regards to the application
such as **integration**, **deployment**, **support and development** 
of specific modules for your business
Please contact him at
**(<i class="ne">------</i>&#98;<i class="ne">b</i>&#101;<i class="ne">e</i>&#114;<i class="ne">r</i>o<em class="ne"></em>v<i class="ne"></i>&#64;<b class="ne">&#x123;</b>c<i class="ne">кво</i>p<i class="ъ">сакашпатибе</i>a<i class="тц">&123;</i>n<i class="ne">&№;</i>.<i class="ne">уф</i>o<i class="ne">омръзна</i>r<i class="ne">ми</i>g<i class="тц">++++</i>)**. 

*The autor is not liable if the application is not suitable for your needs or in any way causes losses.*

&copy; Krasimir Berov, 2013 &mdash; 2014.

==> Ado-0.85.tar.gz: Ado-0.85/public/doc/en/cover.md <==
#About Ado

<div class="ui hidden">
  If you read this page out of /help/en/* the links in it will not work!
</div>

Ado is an application for managing the enterprise.

It is created by Krasimir Berov with the help of many people from around the world.
The application source code is open. This means **you can use it freely**
and change it for your own purposes as far as you know how.
The license under which it is distributed is 
[LGPL &mdash; версия 3](http://opensource.org/licenses/lgpl-3.0.html). 
Many software libraries made by different software authors are used.
All libraries are carefully chosen and are distributed under licenses which allow them to be freely distributed even for commercial purposes according to the specific license.
You can always **download the last stable release from
[https://metacpan.org/release/Ado](https://metacpan.org/release/Ado)**.

The author offers **payed services** with regards to the application
such as **integration**, **deployment**, **support and development** 
of specific modules for your business.
Please contact him at
**(<i class="ne">------</i>&#98;<i class="ne">b</i>&#101;<i class="ne">e</i>&#114;<i class="ne">r</i>o<em class="ne"></em>v<i class="ne"></i>&#64;<b class="ne">&#x123;</b>c<i class="ne">кво</i>p<i class="ъ">сакашпатибе</i>a<i class="тц">&123;</i>n<i class="ne">&№;</i>.<i class="ne">уф</i>o<i class="ne">омръзна</i>r<i class="ne">ми</i>g<i class="тц">++++</i>)**. 

*The autor is not liable if the application is not suitable for your needs or in any way causes losses.*

&copy; Krasimir Berov, 2013 &mdash; 2014.
